@@ -36,6 +36,7 @@ em_vmat22(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
 
 
 from gmat.uvlmm.varcom import pxem_mme, pxem_vmat
+gmat_lst = [a[0], b[0], a[0] * a[0], a[0]*b[0], b[0]*b[0]]
 pxem_mme(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1e-08)
 pxem_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
 
@@ -43,6 +44,10 @@ from gmat.uvlmm.varcom import pxem_mme2, pxem_vmat2
 pxem_mme2(y, xmat, zmat_lst, gmat_inv_lst, init=None, maxiter=100, cc_par=1e-08)
 pxem_vmat2(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
 
+from gmat.uvlmm.varcom import ai_vmat, ai_mme
+ai_vmat(y, xmat, zmat_lst, gmat_lst, init=None, maxiter=100, cc_par=1e-08)
+
+
 
 
 # Estimate the variances
