@@ -2,4 +2,4 @@ from gmat.uvlmm.varcom.em import em_mme, em_vmat
 from gmat.uvlmm.varcom.em import em_mme2, em_vmat2, em_mme22, em_vmat22
 from gmat.uvlmm.varcom.pxem import pxem_mme, pxem_mme2, pxem_vmat, pxem_vmat2
 
-from gmat.uvlmm.varcom.ai import ai_vmat
+from gmat.uvlmm.varcom.ai import ai_vmat, ai_mme
